@@ -2,7 +2,7 @@
 # PODNAME: githooks.pl
 # ABSTRACT: Git::Hooks driver script
 
-use strict;
+use 5.016;
 use warnings;
 use Git::Hooks;
 
@@ -20,7 +20,7 @@ githooks.pl - Git::Hooks driver script
 
 =head1 VERSION
 
-version 2.14.0
+version 3.1.0
 
 =head1 AUTHOR
 
@@ -28,7 +28,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
